%define fontdir %{_datadir}/fonts/%{name}
%define catalogue %{_sysconfdir}/X11/fontpath.d

Summary:            Raw VBI, Teletext and Closed Caption decoding library
Name:               zvbi
Version:            0.2.44
Release:            1%{?dist}
License:            LGPLv2+ and GPLv2+ and BSD
URL:                https://github.com/zapping-vbi/zvbi
Source0:            https://github.com/zapping-vbi/zvbi/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:            zvbid.service
Patch3000:          %{name}-0.2.24-tvfonts.patch
Patch3001:          %{name}-0.2.25-openfix.patch

BuildRequires:      make gcc-c++
BuildRequires:      autoconf automake libtool
BuildRequires:      doxygen gettext-devel libpng-devel libICE-devel
BuildRequires:      bdftopcf mkfontdir systemd-units fontconfig tzdata


%description
The Zapping VBI library, in short ZVBI, provides functions to capture and decode VBI data. It is 
written in plain ANSI C with few dependencies on other tools and libraries, licensed under GPL. 


%package devel
Summary:            Development files for zvbi
Requires:           %{name} = %{version}-%{release}

%description devel
This package provides development files for zvbi.


%package fonts
Summary:            Fonts from zvbi converted to X11
BuildArch:	        noarch
Provides:           xawtv-tv-fonts >= 3.95

%description fonts
This package provides fonts from zvbi converted for use with X11.


%prep
%autosetup -p1


%build
./autogen.sh
# not set --enable-static=no, because static libs are needed to build x11font during compile
# time to convert zvbi fonts into x11 fonts. 
%configure --disable-rpath --enable-v4l --enable-dvb --enable-proxy

sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

%make_build

# generate fonts, fonts.alias, fonts.dir
pushd contrib
./x11font
for font in *.bdf
do
    bdftopcf $font | gzip -9 -c > ${font%.bdf}.pcf.gz
done
mkfontdir -x .bdf .
cat >fonts.alias <<EOF
teletext   -ets-teletext-medium-r-normal--*-200-75-75-c-120-iso10646-1
EOF
popd


%install
mkdir -p %{buildroot}%{fontdir}
%make_install

mkdir -p %{buildroot}%{_unitdir}
install -m644 %{SOURCE1} %{buildroot}%{_unitdir}/zvbid.service
rm -rf %{buildroot}%{_initrddir}

install -pm0644 contrib/*.pcf.gz %{buildroot}%{fontdir}
install -pm0644 contrib/fonts.* %{buildroot}%{fontdir}
touch %{buildroot}%{fontdir}/fonts.cache-1

mkdir -p %{buildroot}%{catalogue}
ln -sf %{fontdir} %{buildroot}%{catalogue}/%{name}

%find_lang %{name}

find %{buildroot}%{_libdir} -name '*.a' -delete


%check
cd test
make check


%post
%systemd_post zvbid.service

%preun
%systemd_preun zvbid.service

%postun
%systemd_postun_with_restart zvbid.service


%files -f %{name}.lang
%license COPYING.md
%doc AUTHORS BUGS ChangeLog NEWS README.md TODO
%{_bindir}/%{name}*
%{_sbindir}/zvbid
%{_unitdir}/zvbid.service
%{_libdir}/libzvbi.so.0*
%{_libdir}/libzvbi-chains.so.0*
%exclude %{_libdir}/*.la
%{_mandir}/man1/zvbi*1*


%files devel
%{_includedir}/libzvbi.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}-0.2.pc


%files fonts
%dir %{_datadir}/fonts/%{name}
%{fontdir}/*.gz
%{fontdir}/fonts.dir
%{fontdir}/fonts.alias
%{catalogue}/%{name}
%ghost %{fontdir}/fonts.cache-1


%changelog
* Tue Mar 11 2025 Upgrade Robot <upbot@opencloudos.tech> - 0.2.44-1
- [Type] security
- [DESC] Upgrade to version 0.2.44, fix CVEs: CVE-2025-2173, CVE-2025-2174, CVE-2025-2175, 
  CVE-2025-2176, CVE-2025-2177

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.2.35-4
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.2.35-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.2.35-2
- Rebuilt for OpenCloudOS Stream 23.05

* Thu Apr 20 2023 Wang Guodong <gordonwwang@tencent.com> - 0.2.35-1
- initial build
